/***************************************************************************
 *   This file is part of awesome-widgets                                  *
 *                                                                         *
 *   awesome-widgets is free software: you can redistribute it and/or      *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   awesome-widgets is distributed in the hope that it will be useful,    *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with awesome-widgets. If not, see http://www.gnu.org/licenses/  *
 ***************************************************************************/

#pragma once

#include <QLocale>
#include <QVariant>

#include "awpluginformatsettings.h"


template<typename Formatter> class AWPluginFormatter {

public:
    static constexpr double KBinBytes = 1024.0;
    static constexpr double MBinBytes = 1024.0 * KBinBytes;
    static constexpr double GBinBytes = 1024.0 * MBinBytes;

    virtual ~AWPluginFormatter() = default;
    AWPluginFormatter(AWPluginFormatter &) = delete;
    void operator=(const AWPluginFormatter &) = delete;

    virtual QString format(const QVariant &_value, const AWPluginFormatSettings &_settings) = 0;
    static Formatter &instance()
    {
        static auto instance = loadInstance();
        return instance;
    };
    virtual void load() {};
    static QLocale locale(const AWPluginFormatSettings &_settings)
    {
        return _settings.translate ? QLocale::system() : QLocale::c();
    }

protected:
    AWPluginFormatter() = default;
    static Formatter loadInstance()
    {
        auto instance = Formatter();
        instance.load();
        return instance;
    };
};
